import React from "react";
import PropTypes from "prop-types";
import * as dropEffects from "../../utils/dropEffects";

const insideStyle = {
  backgroundColor: "#cccccc",
  opacity: 0.5,
};

const DropTarget = props => {
  const [isOver, setIsOver] = React.useState(false);

  const dragOver = ev => {
    ev.preventDefault();
    ev.dataTransfer.dropEffect = props.dropEffect;
  };

  const drop = ev => {
    const droppedItem = ev.dataTransfer.getData("drag-item");
    console.log('dropItem', droppedItem)
    if (droppedItem) {
      props.onItemDropped(droppedItem);
    }
    setIsOver(false);
  };

  const dragEnter = ev => {
    console.log('dragEnter', ev)
    ev.dataTransfer.dropEffect = props.dropEffect;
    setIsOver(true);
  };

  const dragLeave = () => setIsOver(false);

  return (
    <div
      onDragOver={ dragOver }
      onDrop={ drop }
      onDragEnter={ dragEnter }
      onDragLeave={ dragLeave }
      style={ { width: "100%", minHeight: "100px", border: "1px solid black", ...(isOver ? insideStyle : {}) } }
    >
      { props.children }
    </div>
  );
};

DropTarget.propTypes = {
  onItemDropped: PropTypes.func.isRequired,
  dropEffect: PropTypes.string,
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]).isRequired,
};

DropTarget.defaultProps = {
  dropEffect: dropEffects.All,
};

export default DropTarget;